### Name: gcModify
### Title: Modify Ragraph Objects and Replot them
### Aliases: gcModify gcModify,graphdata-method
### Keywords: hplot methods

### ** Examples

data("hsod")
library(flexclust)
set.seed(1111)
cl1 <- qtclust(hsod, radius = 2,
               family = kccaFamily(dist = distEuclidean,
                    cent = colMeans), save.data = TRUE)

## create Ragraph object from kcca object with gcExplorer
graph <- gcExplorer(cl1, theme = "blue", node.function = node.size)

## extract and modify clsim
clsim <- clusterSim(cl1)
clsim[clsim < 0.5] <- 0

## use modified clsim on Ragraph object to remove edges (<0.5)
gcModify(graph, clsim)

## use nodeDep=TRUE to delete nodes without edges
gcModify(graph, clsim, nodeDep = TRUE, zoom = "none")

## use zoom="auto" to center and maximize subgraph
gcModify(graph, clsim, nodeDep = TRUE, zoom = "auto")

## Not run: 
##D ## R package symbols is available from Rforge: 
##D ## http://r-forge.r-project.org/projects/symbols/
##D 
##D require("symbols")
##D 
##D ## create a grid based plotting function: plot cluster data and centers in matplot.
##D gmatplot <- function (object, cluster, bgdata) {
##D         grid.rect()
##D         data <- object@data@get("designMatrix")
##D         ylimits <- c(min(data, na.rm = TRUE), max(data, na.rm = TRUE))
##D         index <- (object@cluster == cluster)
##D         nodedata <- data[index,]
##D         symb.matplot(1:ncol(nodedata), t(nodedata), type = "l", 
##D                 col = "gray", ylim = ylimits, pch = 1)
##D         center <- object@centers[cluster,]
##D         symb.matplot(1:ncol(object@centers), center, type = "l",
##D                 col = "red", ylim = ylimits, pch = 1)
##D }
##D ## use grid based node function to draw nodes
##D gcModify(graph, clsim, nodeDep = TRUE, zoom = "auto", 
##D          node.function = gmatplot)
## End(Not run)



